@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.220 2007/11/16 08:44:37 albertel Exp $
+# $Id: caparesponse.pm,v 1.221 2008/02/01 23:00:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -787,6 +787,12 @@ sub end_numericalresponse {
     }
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
+        if (($tag eq 'formularesponse') && ($target eq 'analyze')) {
+            my $type = &Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.type');
+            if ($type eq 'exam') {
+                $increment = &Apache::response::repetition();
+            }
+        }
 	&Apache::lonxml::increment_counter($increment,"$partid.$id");
 	if ($target eq 'analyze') {
 	    &Apache::lonhomework::set_bubble_lines();
