@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.236 2008/01/14 14:32:14 raeburn Exp $
+# $Id: inputtags.pm,v 1.237 2008/01/28 21:42:28 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -672,7 +672,8 @@ sub decideoutput {
 		if (($symb ne '') 
 		    &&
 		    ($env{'course.'.$env{'request.course.id'}.
-			      '.disable_receipt_display'} ne 'yes')) { 
+			      '.disable_receipt_display'} ne 'yes') &&
+                    ($Apache::lonhomework::type ne 'practice')) { 
 		    $message.=(($target eq 'web')?'<br />':' ').
 			&mt('Your receipt is [_1]',
 			    (&Apache::lonnet::receipt($Apache::inputtags::part).
@@ -844,6 +845,10 @@ sub decideoutput {
 	$message.= $computer;
 	$added_computer_text=1;
     }
+    if ($Apache::lonhomework::type eq 'practice') {
+       $message.='<br />'.&mt('Submissions to practice problems are not permanently recorded.');
+    }
+
     return ($button,$css_class,$message,$previousmsg);
 }
 
