@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.147 2007/10/15 09:47:29 foxr Exp $
+# $Id: optionresponse.pm,v 1.149 2008/02/01 22:05:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,8 +70,9 @@ sub start_optionresponse {
     $result=&Apache::response::meta_package_write('optionresponse');
   } elsif ($target eq 'analyze') {
     my $part_id="$Apache::inputtags::part.$id";
+    $Apache::lonhomework::analyze{"$part_id.type"} = 'optionresponse';
     push (@{ $Apache::lonhomework::analyze{"parts"} },$part_id);
-    push (@{ $Apache::lonhomeowrk::analyze{"$part_id.bubble_lines"} }, 1);
+    push (@{ $Apache::lonhomework::analyze{"$part_id.bubble_lines"} }, 1);
 
   }
   return $result;
