@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.416 2008/01/15 03:09:09 raeburn Exp $
+# $Id: structuretags.pm,v 1.417 2008/01/28 21:42:28 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -862,6 +862,10 @@ sub start_problem {
 		$form_tag_start.= ' />'.&mt('&nbsp;Show&nbsp;All&nbsp;Foils').
 		    '</label>';
 	    }
+            if ($Apache::lonhomework::type eq 'practice') {
+               $form_tag_start.='<span class="LC_info"><h3>'.&mt('Practice Problem').'</h3></span>'.
+                                '<span class="LC_info">'.&mt('Submissions are not permanently recorded').'</span>';
+            }
 	    $form_tag_start.='<hr />';
 	}
 
