@@ -29,11 +29,12 @@ use Apache::lonnet;
 use LONCAPA;
 
 sub retrieve_instcodes {
-    my ($coursecodes,$codedom,$totcodes) = @_;
+    my ($coursecodes,$codedom) = @_;
+    my $totcodes;
     my %courses = &Apache::lonnet::courseiddump($codedom,'.',1,'.','.','.',                                                undef,undef,'Course');
-    foreach my $course (keys %courses) {
-        if ($courses{$course} =~ m/^[^:]*:([^:]+)/) {
-            $$coursecodes{$course} = &unescape($1);
+    foreach my $course (keys(%courses)) {
+        if (ref($courses{$course}) eq 'HASH') {
+            $$coursecodes{$course} = $courses{$course}{'inst_code'};
             $totcodes ++;
         }
     }
