@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # "About Me" Personal Information
 #
-# $Id: lonaboutme.pm,v 1.65 2007/07/27 00:17:17 albertel Exp $
+# $Id: lonaboutme.pm,v 1.69 2008/01/20 22:25:05 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -69,7 +69,7 @@ sub handler {
 # ------------------------------------------------------------ Get Query String
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
 					    ['forceedit','forcestudent',
-					     'register']);
+					     'register','popup']);
 
 # ----------------------------------------------- Available Portfolio file display 
     if (($target ne 'tex') && ($action eq 'portfolio')) {
@@ -115,12 +115,14 @@ sub handler {
     my %courseenv=&Apache::lonnet::dump('environment',$cdom,$cnum);
     if ($target ne 'tex') {
 	my $rss_link = &Apache::lonrss::rss_link($cnum,$cdom);
+        my $args = {'function' => $forcestudent,
+                    'domain'   => $cdom,
+                    'force_register' => $forceregister};
+        if ($env{'form.popup'}) {
+            $args->{'no_nav_bar'} = 1;
+        }
 	my $start_page = 
-	    &Apache::loncommon::start_page("Personal Information", $rss_link,
-					   {'function'       => $forcestudent,
- 					    'domain'         => $cdom,
-					    'force_register' =>
-						            $forceregister,});
+	    &Apache::loncommon::start_page("Personal Information",$rss_link,$args);
 	$r->print($start_page);
 	$r->print('<h1>'.&Apache::loncommon::plainname($cnum,$cdom).'</h1>');
     } else {
@@ -133,7 +135,7 @@ sub handler {
     }
     if ($target ne 'tex') {
 	$r->print('<h3>'.&Apache::lonnet::domain($cdom,'description').'</h3>'.
-		  '<p>'.&Apache::loncommon::messagewrapper('Send me a message',$cnum,$cdom).'</p>'.&Apache::lonrss::advertisefeeds($cnum,$cdom));
+		  '<p>'.&Apache::loncommon::messagewrapper(&mt('Send me a message'),$cnum,$cdom).'</p>'.&Apache::lonrss::advertisefeeds($cnum,$cdom));
     } else {
 	$r->print('\textbf{'.&Apache::lonnet::domain($cdom,'description').'}\\\\');
     }
@@ -147,14 +149,14 @@ sub handler {
        if ($forcestudent or $target eq 'tex') { $allowed=0; }
  
        if ($allowed) {
-           my $query_string = &build_query_string({'forcestudent' => '1',});
+           my $query_string = &build_query_string({'forcestudent' => '1','popup' => $env{'form.popup'}});
 	   $r->print('<p><b>'.&mt('Privacy Note').':</b> '.
 		     &mt('The information you submit can be viewed by anybody who is logged into LON-CAPA. Do not provide information that you are not ready to share publicly.').
 		     '</p>'.
-		     &Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes','Help with filling in text boxes').'</p><p><a href="'.$r->uri.$query_string.'">Show Public View</a>'.
+		     &Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes')).'</p><p><a href="'.$r->uri.$query_string.'">'.&mt('Show Public View').'</a>'.
 		     &Apache::loncommon::help_open_topic('Uploaded_Templates_PublicView').'</p>');
        } elsif ($privleged && $target ne 'tex') {
-           my $query_string = &build_query_string({'forceedit' => '1',});
+           my $query_string = &build_query_string({'forceedit' => '1','popup' => $env{'form.popup'}});
 	   $r->print('<p><a href="'.$r->uri.$query_string.'"><font size="+1">'.
 		     &mt('Edit').'</font></a></p>');
        }
@@ -207,12 +209,13 @@ sub handler {
        if ($allowed) {
            $r->print(
 	 '<form method="post">
-               <input type="submit" name="delupl" value="Delete Photo" />
+               <input type="submit" name="delupl" value="'.&mt('Delete Photo').'" />
           </form>'.
 	 '<form method="post" enctype="multipart/form-data">'.
          '<h3>'.&mt('Upload a Photo').'</h3>'.
-         '<input type="file" name="uploaddoc" size="50">'.
-         '<input type="submit" name="storeupl" value="Upload">'.
+         '<input type="file" name="uploaddoc" size="50" />'.
+         '<input type="submit" name="storeupl" value="'.&mt('Upload').'" />'.
+         '<input type="hidden" name="popup" value="'.$env{'form.popup'}.'" />'.
 	 '</form><form method="post">');
 
        }
@@ -242,6 +245,10 @@ sub handler {
 	  }
        }
        if ($allowed) {
+           if ($env{'form.popup'}) {
+               $r->print('<input type="hidden" name="popup" value="'.
+                         $env{'form.popup'}.'" />');
+           }
 	   $r->print('</form>');
        }
        if ($target ne 'tex') {$r->print('<br />');} else {$r->print('\\\\');}
@@ -281,6 +288,9 @@ sub handler {
 	}
     }
     if ($target ne 'tex') {
+        if ($env{'form.popup'}) {
+            $r->print('<p><a href="javascript:window.close()">'.&mt('Close window').'</a>');
+        }
 	$r->print(&Apache::loncommon::end_page());
     } else {
 	$r->print('\end{document}');
