@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Evaluate
 #
-# $Id: lonevaluate.pm,v 1.21 2007/05/02 01:33:49 albertel Exp $
+# $Id: lonevaluate.pm,v 1.24 2007/11/28 01:46:12 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,7 @@ use Apache::lonnet;
 use Apache::Constants qw(:common);
 use Apache::loncommon();
 use Apache::lonenc();
+use Apache::lonlocal;
 use LONCAPA();
 
 sub handler {
@@ -99,20 +100,20 @@ ENDJS
 
             my $start_page = 
 	        &Apache::loncommon::start_page('Evaluate Resource',$js);
-	    $r->print(<<ENDHEADER);
-$start_page
-<h1>Thank you for your input!</h1>
-ENDHEADER
-       $r->print('Saving feedback: '.
-           &Apache::lonnet::put('nohist_resevaldata',\%currenteval,$rdomain,$rauth));
+	    $r->print('
+'.$start_page.'
+<h1>'.&mt('Thank you for your input!').'</h1>
+');
+       $r->print(&mt('Saving feedback: [_1]',
+		     &Apache::lonnet::put('nohist_resevaldata',\%currenteval,$rdomain,$rauth)));
            unless ($already) {
-	       $r->print('<br />Logging first evaluation');
+	       $r->print('<br />'.&mt('Logging first evaluation'));
            }
            $r->print(
             '<script type="text/javascript">setTimeout("goback()",2000);</script>'.&Apache::loncommon::end_page());
            return OK;
         } else {
-	    $warning='Please fill out all fields below';
+	    $warning=&mt('Please fill out all fields below');
         }
    
     }
@@ -134,55 +135,72 @@ ENDHEADER
        }       
     }
 # ------------------------------------------------------- Print out eval screen
-    my $standardoptions=(<<ENDOPTIONS);
+    my %lt=&Apache::lonlocal::texthash('a' => 'Strongly Disagree',
+				       'b' => 'Disagree',
+				       'c' => 'Neutral',
+				       'd' => 'Agree',
+				       'e' => 'Strongly Agree',);
+    my $standardoptions='';
+    $standardoptions = (<<ENDOPTIONS);
 <option value="0">-</option>
-<option value="1">Strongly Disagree</option>
-<option value="2">Disagree</option>
-<option value="3">Neutral</option>
-<option value="4">Agree</option>
-<option value="5">Strongly Agree</option>
+<option value="1">$lt{'a'}</option>
+<option value="2">$lt{'b'}</option>
+<option value="3">$lt{'c'}</option>
+<option value="4">$lt{'d'}</option>
+<option value="5">$lt{'e'}</option>
 ENDOPTIONS
-    
+
     my $start_page = &Apache::loncommon::start_page('Evaluate Resource');
     my $end_page   = &Apache::loncommon::end_page();
+
+     %lt=&Apache::lonlocal::texthash(
+       'pleaserank' => 'Please rank the following criteria:',
+       'correct'    => 'The material appears to be correct',
+       'helpful'    => 'The material is helpful',
+       'depth'      => 'The material is covered with sufficient depth',
+       'clear'      => 'The material is presented in a clear way',
+       'technical'  => 'The resource is technically correct (loads fast enough, does not produce errors, links work, etc)',
+       'comments'   => 'Any comments?',
+       'submit'     => 'Submit Evaluation',
+    );
     $r->print(<<ENDDOCUMENT);
 $start_page
-<tt>$title</tt><br /><br />
+<h2><tt>$title</tt></h2><br /><br />
 <h3><font color="red">$warning</font></h3>
-Please rank the following criteria:
+$lt{'pleaserank'}<br />
 <form method="post" name="evaluation" action="/adm/evaluate">
 <input type="hidden" name="submiteval" value="true" />
 <input type="hidden" name="postdata" value="$showurl" />
-The material appears to be correct
+<hr />
+$lt{'correct'}
 <br /><select name="correct">
 $standardoptions
 </select>
 <hr />
-The material is helpful
+$lt{'helpful'}
 <br /><select name="helpful">
 $standardoptions
 </select>
 <hr />
-The material is covered with sufficient depth
+$lt{'depth'}
 <br /><select name="depth">
 $standardoptions
 </select>
 <hr />
-The material is presented in a clear way
+$lt{'clear'}
 <br /><select name="clear">
 $standardoptions
 </select>
 <hr />
-The resource is technically correct 
-(loads fast enough, does not produce errors, links work, etc) 
+$lt{'technical'}
 <br /><select name="technical">
 $standardoptions
 </select>
 <hr />
-Any comments?
+$lt{'comments'}
 <br /><textarea name="comments" cols="40" rows="5">$oldcomments</textarea>
 <script type="text/javascript">$dialold</script>
-<br /><input type="submit" value="Submit Evaluation" />
+<br /><input type="submit" value="$lt{'submit'}" />
 </form>
 $end_page
 ENDDOCUMENT
