@@ -142,7 +142,6 @@ SCRIPT_TWO
     $r->print($start_page);
 
     my $width = ($stayOnPage) ? '95%' : '600';
-
     $r->print('<table id="LC_helpmenu" width="'.$width.'">');
 
     my $general_help = &Apache::loncommon::general_help();
@@ -153,36 +152,35 @@ SCRIPT_TWO
     <fieldset><legend><img src="$location/lonIcons/minilogo.gif" height='20' width='29' valign='bottom' />&nbsp;&nbsp;LON-CAPA help/support</legend>
  <table id="LC_helpmenu_links">
    <tr>
-	<td><a href="/adm/help/$general_help.hlp" target="bodyframe">
-		  <img src="$location/help/gif/smallHelp.gif" border="0" alt="(General help)" valign="middle" />&nbsp;General Help</a>&nbsp;</td>
+	<td><span class="LC_nobreak"><a href="/adm/help/$general_help.hlp" target="bodyframe">
+		  <img src="$location/help/gif/smallHelp.gif" border="0" alt="(General help)" valign="middle" />&nbsp;General Help</a>&nbsp;</span></td>
 END
     if ($component_url) {
-	$r->print("<td><a href=\"$component_url\" target=\"bodyframe\">".
-		  '<img src="'.$location.'/help/gif/smallHelp.gif" border="0" alt="(Topic help)" valign="middle" />&nbsp;'.$topic.'</a>&nbsp;</td>');
+	$r->print("<td><span class=\"LC_nobreak\"><a href=\"$component_url\" target=\"bodyframe\">".
+		  '<img src="'.$location.'/help/gif/smallHelp.gif" border="0" alt="(Topic help)" valign="middle" />&nbsp;'.$topic.'</a>&nbsp;</span></td>');
     }
     if ($requestmail =~ m/^[^\@]+\@[^\@]+$/) {
         $r->print('
-            <td>&nbsp;<a href="javascript:gohelpdesk()"><img src="'.$location.'/lonIcons/helpdesk.gif" border="0" alt="(Ask helpdesk)" valign="middle" />&nbsp;Ask helpdesk</a>&nbsp;</td>');
+            <td><span class="LC_nobreak">&nbsp;<a href="javascript:gohelpdesk()"><img src="'.$location.'/lonIcons/helpdesk.gif" border="0" alt="(Ask helpdesk)" valign="middle" />&nbsp;Ask helpdesk</a>&nbsp;</span></td>');
     }
     if ($faq && $env{'user.adv'}) {
         $r->print(<<END);
-            <td>
-             &nbsp;<a href="$faqbaseurl/fom/cache/$faq.html" target="bodyframe"><img src="$location/lonMisc/smallFAQ.gif" border="0" alt="(FAQ)" valign="middle" />&nbsp;FAQ</a>&nbsp;
+             <td><span class="LC_nobreak">&nbsp;<a href="$faqbaseurl/fom/cache/$faq.html" target="bodyframe"><img src="$location/lonMisc/smallFAQ.gif" border="0" alt="(FAQ)" valign="middle" />&nbsp;FAQ</a>&nbsp;</span>
             </td>
 END
     }
     if ($env{'user.adv'}) {
         $r->print(<<END);
-            <td>&nbsp;<b><a href="$bugurl" target="bodyframe"><img src="$location/lonMisc/smallBug.gif" border="0" alt="(Report a bug)" valign="middle" />&nbsp;Report a bug</a>&nbsp;</b></td>
+            <td><span class="LC_nobreak"&nbsp;<b><a href="$bugurl" target="bodyframe"><img src="$location/lonMisc/smallBug.gif" border="0" alt="(Report a bug)" valign="middle" />&nbsp;Report a bug</a>&nbsp;</b></span></td>
 END
     }
     if ($stayOnPage) {
         $r->print(<<END);
-            <td>&nbsp;<a href="$origurl" target="_top"><img src="$location/lonIcons/move_up.gif" border="0" alt="(Return to last location)" valign="middle" />&nbsp;Return to last location</a>&nbsp;</td>
+            <td><span class="LC_nobreak">&nbsp;<a href="$origurl" target="_top"><img src="$location/lonIcons/move_up.gif" border="0" alt="(Return to last location)" valign="middle" />&nbsp;Return to last location</a>&nbsp;</span></td>
 END
     } else {
         $r->print(<<END);
-            <td>&nbsp;<a href="javascript:window.close()" target="_top"><img src="$location/lonIcons/closepage.gif" border="0" alt="(Close window)" valign="bottom" />&nbsp;Close</a>&nbsp;</td>
+            <td><span class="LC_nobreak"&nbsp;<a href="javascript:window.close()" target="_top"><img src="$location/lonIcons/closepage.gif" border="0" alt="(Close window)" valign="bottom" />&nbsp;Close</a>&nbsp;</span></td>
 END
     }
     $r->print(<<END);
@@ -190,7 +188,7 @@ END
  </table>
 </fieldset>
   </td>
-  <td width='5'>&nbsp;</td>
+  <td width='100%'>&nbsp;</td>
  </tr>
  <tr height='5'>
   <td colspan='3' height='5'>&nbsp;</td>
