@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.233 2008/01/15 16:53:27 www Exp $
+# $Id: lonmenu.pm,v 1.234 2008/02/03 05:07:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -415,7 +415,7 @@ sub innerregister {
         ###
         my $editbutton = '';
         if ($env{'user.author'}) {
-            if ($env{'request.role'}=~/^(ca|au)/) {
+            if ($env{'request.role'}=~/^(aa|ca|au)/) {
                 # Set defaults for authors
                 my ($top,$bottom) = ('con-','struct');
                 my $action = "go('/priv/".$env{'user.name'}."');";
@@ -428,6 +428,11 @@ sub innerregister {
                     ($top,$bottom) = ('co con-','struct');
                     $action = "go('/priv/".$caname."');";
                     $desc = "Enter construction space as co-author";
+                } elsif ($env{'request.role'} =~ /^aa/) {
+                    ($cadom,$caname)=($env{'request.role'}=~/($match_domain)\/($match_username)$/);
+                    ($top,$bottom) = ('co con-','struct');
+                    $action = "go('/priv/".$caname."');";
+                    $desc = "Enter construction space as assistant co-author";
                 }
                 # Check that we are on the correct machine
                 my $home = &Apache::lonnet::homeserver($caname,$cadom);
@@ -1087,11 +1092,12 @@ sub rawconfig {
         } elsif ($pro eq 'author') {
             if ($author) {
                 if ((($prt eq 'rca') && ($env{'request.role'}=~/^ca/)) ||
+                    (($prt eq 'raa') && ($env{'request.role'}=~/^aa/)) || 
                     (($prt eq 'rau') && ($env{'request.role'}=~/^au/))) {
                     # Check that we are on the correct machine
                     my $cadom=$requested_domain;
                     my $caname=$env{'user.name'};
-                    if ($prt eq 'rca') {
+                    if (($prt eq 'rca') || ($prt eq 'raa')) {
 		       ($cadom,$caname)=
                                ($env{'request.role'}=~/($match_domain)\/($match_username)$/);
                     }                       
