@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.209 2007/06/15 23:01:07 albertel Exp $
+# $Id: lonmeta.pm,v 1.211 2008/01/24 10:05:13 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1074,7 +1074,7 @@ sub print_dynamic_metadata {
             $table .= '</table>'.$/;
             $r->print($table);
         } else {
-            $r->print('No new dynamic data found.');
+            $r->print(&mt('No new dynamic data found.'));
         }
     } else {
         $r->print('<h4>'.
@@ -1221,13 +1221,11 @@ ENDDEL
 	}
 	$r->print('<br />'.$bombs);
     } else {
-        my $displayfile='Catalog Information for '.$disuri;
+        my $displayfile=&mt('Catalog Information for [_1]',$disuri);
         if ($disuri=~/\/default$/) {
             my $dir=$disuri;
             $dir=~s/default$//;
-            $displayfile=
-                &mt('Default Cataloging Information for Directory').' '.
-                $dir;
+            $displayfile=&mt('Default Cataloging Information for Directory [_1]',$dir);
         }
         %Apache::lonpublisher::metadatafields=();
         %Apache::lonpublisher::metadatakeys=();
@@ -1332,7 +1330,7 @@ ENDEDIT
                         ".description"}.'</strong>').'<br />');
                 }
 	    } else {
-		$r->print('<a href="'.$uri.'?changecourse=true">This resource is not associated with a course.</a><br />');
+		$r->print('<a href="'.$uri.'?changecourse=true">'.&mt('This resource is not associated with a course.').'</a><br />');
 	    }
 	}
 	if (@added_order) {
