@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.109 2007/07/17 21:11:49 albertel Exp $
+# $Id: lonpreferences.pm,v 1.113 2008/01/21 04:30:05 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -168,11 +168,11 @@ sub verify_and_change_languages {
     if ($newlanguage) {
         &Apache::lonnet::put('environment',{'languages' => $newlanguage});
         &Apache::lonnet::appenv('environment.languages' => $newlanguage);
-        $message='Set new preferred languages to '.$newlanguage;
+        $message=&mt('Set new preferred languages to ').'<tt>"'.$newlanguage.'"</tt>.';
     } else {
         &Apache::lonnet::del('environment',['languages']);
         &Apache::lonnet::delenv('environment\.languages');
-        $message='Reset preferred language';
+        $message=&mt('Reset preferred language.');
     }
     $r->print(<<ENDVCSCREEN);
 $message
@@ -262,11 +262,11 @@ sub verify_and_change_texengine {
     if ($newtexengine) {
         &Apache::lonnet::put('environment',{'texengine' => $newtexengine});
         &Apache::lonnet::appenv('environment.texengine' => $newtexengine);
-        $message='Set new preferred math display to '.$newtexengine;
+        $message=&mt('Set new preferred math display to ').'<tt>"'.$newtexengine.'"</tt>.';
     } else {
         &Apache::lonnet::del('environment',['texengine']);
         &Apache::lonnet::delenv('environment\.texengine');
-        $message='Reset preferred math display.';
+        $message=&mt('Reset preferred math display.');
     }
 
 
@@ -467,14 +467,20 @@ sub screennamechanger {
         ('environment',['screenname','nickname']);
     my $screenname=$userenv{'screenname'};
     my $nickname=$userenv{'nickname'};
+    my %lt = &Apache::lonlocal::texthash(
+                                          text_screenname  => 'New screenname (shown if you post anonymously):',
+                                          text_nickname  => 'New nickname (shown if you post non-anonymously):',
+                                          text_submit => 'Change',
+                                        );
     $r->print(<<ENDSCREEN);
 <form name="prefs" action="/adm/preferences" method="post">
 <input type="hidden" name="action" value="verify_and_change_screenname" />
-<br />New screenname (shown if you post anonymously):
+<br />$lt{'text_screenname'}
 <input type="text" size="20" value="$screenname" name="screenname" />
-<br />New nickname (shown if you post non-anonymously):
+<br />$lt{'text_nickname'}
 <input type="text" size="20" value="$nickname" name="nickname" />
-<input type="submit" value="Change" />
+<br />
+<input type="submit" value="$lt{'text_submit'}" />
 </form>
 ENDSCREEN
 }
@@ -490,11 +496,11 @@ sub verify_and_change_screenname {
     if ($newscreen) {
         &Apache::lonnet::put('environment',{'screenname' => $newscreen});
         &Apache::lonnet::appenv('environment.screenname' => $newscreen);
-        $message='Set new screenname to '.$newscreen;
+        $message=&mt('Set new screenname to ').'<tt>"'.$newscreen.'."</tt>.';
     } else {
         &Apache::lonnet::del('environment',['screenname']);
         &Apache::lonnet::delenv('environment\.screenname');
-        $message='Reset screenname';
+        $message=&mt('Reset screenname.');
     }
 # Nickname
     $message.='<br />';
@@ -503,11 +509,11 @@ sub verify_and_change_screenname {
     if ($newscreen) {
         &Apache::lonnet::put('environment',{'nickname' => $newscreen});
         &Apache::lonnet::appenv('environment.nickname' => $newscreen);
-        $message.='Set new nickname to '.$newscreen;
+        $message.=&mt('Set new nickname to ').'<tt>"'.$newscreen.'"</tt>.';
     } else {
         &Apache::lonnet::del('environment',['nickname']);
         &Apache::lonnet::delenv('environment\.nickname');
-        $message.='Reset nickname';
+        $message.=&mt('Reset nickname.');
     }
     &Apache::lonnet::devalidate_cache_new('namescache',$user.':'.$domain);
     $r->print(<<ENDVCSCREEN);
@@ -618,19 +624,19 @@ sub msgforwardchanger {
                                           crit  => 'Critical only',
                                           reg   => 'Non-critical only',
                                           foad  => 'Forwarding Address(es)',
-                                          mnot  => 'Message Notification Email Address(es)',
+                                          noti  => 'Notification E-mail Address(es)', 
+                                          foad_exmpl => 'e.g. <tt>userA:domain1,userB:domain2,...</tt>',
+                                          mnot  => 'Email Address(es) which should be notified about new LON-CAPA messages', # old: 'Message Notification Email Address(es)',
+                                          mnot_exmpl => 'e.g. <tt>joe@doe.com</tt>',
                                           chg   => 'Change',
                                           email => 'The e-mail address entered in row ',
                                           notv => 'is not a valid e-mail address',
                                           toen => "To enter multiple addresses, enter one address at a time, click 'Change' and then add the next one", 
                                           prme => 'Back to preferences menu',
                                         );
-    my $forwardingHelp = Apache::loncommon::help_open_topic("Prefs_Forwarding",
-							    "What are forwarding ".
-							    "and notification ".
-							    "addresses");
-    my $criticalMessageHelp = Apache::loncommon::help_open_topic("Course_Critical_Message",
-								 "What are critical messages");
+    my $forwardingHelp = &Apache::loncommon::help_open_topic("Prefs_Forwarding");
+    my $notificationHelp = &Apache::loncommon::help_open_topic("Prefs_Notification");
+    my $criticalMessageHelp = &Apache::loncommon::help_open_topic("Course_Critical_Message");
     my @allow_html = split(/,/,$userenv{'notifywithhtml'});
     my %allnot = &get_notifications(\%userenv);
     my $validatescript = &Apache::lonhtmlcommon::javascript_valid_email();
@@ -657,7 +663,7 @@ function validate() {
                 if (addr.indexOf(",") >= 0) {
                     multimsg = "\\n($lt{'toen'}).";
                 }
-                alert("$lt{'email'} "+rownum+": '"+addr+"' $lt{'notv'}."+multimsg);
+                alert("$lt{'email'} "+rownum+" ('"+addr+"') $lt{'notv'}."+multimsg);
                 return;
             }
         }
@@ -693,13 +699,13 @@ $validatescript
     $r->print(<<ENDMSG);
 $jscript
 $message
-$forwardingHelp
+<h3>$lt{'foad'} $forwardingHelp</h3>
 <form name="prefs" action="/adm/preferences" method="post">
 <input type="hidden" name="action" value="verify_and_change_msgforward" />
-$lt{'foad'} (<tt>user:domain,user:domain,...</tt>):
-<input type="text" size="40" value="$msgforward" name="msgforward" /><hr />
-$criticalMessageHelp
-$lt{'mnot'} (<tt>joe\@doe.com</tt>):<br />
+$lt{'foad'} ($lt{'foad_exmpl'}):
+<input type="text" size="40" value="$msgforward" name="msgforward" /><br />
+<h3>$lt{'noti'} $notificationHelp</h3>
+$lt{'mnot'} ($lt{'mnot_exmpl'}):<br />
 ENDMSG
     my @sortforwards = sort (keys(%allnot));
     my $output = &Apache::loncommon::start_data_table().
@@ -707,7 +713,8 @@ ENDMSG
                  '<th>&nbsp;</th>'.
                  '<th>'.&mt('Action').'</th>'.
                  '<th>'.&mt('Notification address').'</th><th>'.
-                 &mt('Types of message to forward to this address').'</th><th>'.
+                 &mt('Types of message for which notification is sent').
+                 $criticalMessageHelp.'</th><th>'.
                  &mt('Excerpt retains HTML tags in message').'</th>'.
                  &Apache::loncommon::end_data_table_header_row();
     my $num = 0;
@@ -790,7 +797,7 @@ ENDMSG
     $num ++;
     $r->print($output);
     $r->print(qq|
-<hr />
+<br /><hr />
 <input type="hidden" name="numnotify" value="$num" />
 <input type="button" value="$lt{'chg'}" onclick="javascript:validate()" />
 <input type="button" value="$lt{'prme'}" onclick="location.href='/adm/preferences'" />
@@ -827,7 +834,7 @@ sub verify_and_change_msgforward {
 	    if (&Apache::lonnet::homeserver($msuser,$msdomain) ne 'no_host') {
                $newscreen.=$msuser.':'.$msdomain.',';
 	   } else {
-               $message.= &mt('No such user: ').$msuser.':'.$msdomain.'<br>';
+               $message.= &mt('No such user: ').'<tt>'.$msuser.':'.$msdomain.'</tt><br>';
            }
         }
     }
@@ -835,8 +842,8 @@ sub verify_and_change_msgforward {
     if ($newscreen) {
         &Apache::lonnet::put('environment',{'msgforward' => $newscreen});
         &Apache::lonnet::appenv('environment.msgforward' => $newscreen);
-        $message .= &mt('Set message forwarding to: ').'<tt>'.$newscreen.
-                    '</tt><br />';
+        $message .= &mt('Set message forwarding to ').'<tt>"'.$newscreen.'"</tt>.'
+                    .'<br />';
     } else {
         &Apache::lonnet::del('environment',['msgforward']);
         &Apache::lonnet::delenv('environment\.msgforward');
@@ -876,26 +883,26 @@ sub verify_and_change_msgforward {
     if ($notification) {
         &Apache::lonnet::put('environment',{'notification' => $notification});
         &Apache::lonnet::appenv('environment.notification' => $notification);
-        $message.=&mt('Set non-critical message notification address(es) to: ').'<tt>'.$notification.'</tt><br />';
+        $message.=&mt('Set non-critical message notification address(es) to ').'<tt>"'.$notification.'"</tt>.<br />';
     } else {
         &Apache::lonnet::del('environment',['notification']);
         &Apache::lonnet::delenv('environment\.notification');
-        $message.=&mt("Non-critical message notification set to 'off'.").'<br />';
+        $message.=&mt("Set non-critical message notification to 'off'.").'<br />';
     }
     if ($critnotification) {
         &Apache::lonnet::put('environment',{'critnotification' => $critnotification});
         &Apache::lonnet::appenv('environment.critnotification' => $critnotification);
-        $message.=&mt('Set critical message notification address(es) to: ').'<tt>'.$critnotification.'</tt><br />';
+        $message.=&mt('Set critical message notification address(es) to ').'<tt>"'.$critnotification.'"</tt>.<br />';
     } else {
         &Apache::lonnet::del('environment',['critnotification']);
         &Apache::lonnet::delenv('environment\.critnotification');
-        $message.=&mt("Critical message notification set to 'off'.").'<br />';
+        $message.=&mt("Set critical message notification to 'off'.").'<br />';
     }
     if ($critnotification || $notification) {
         if ($notify_with_html) {
             &Apache::lonnet::put('environment',{'notifywithhtml' => $notify_with_html});
             &Apache::lonnet::appenv('environment.notifywithhtml' => $notify_with_html);
-            $message.=&mt('Set address(es) to receive excerpts with html retained: ').'<tt>'.$notify_with_html.'</tt>';
+            $message.=&mt('Set address(es) to receive excerpts with html retained ').'<tt>"'.$notify_with_html.'"</tt>.';
         } else {
             &Apache::lonnet::del('environment',['notifywithhtml']);
             &Apache::lonnet::delenv('environment\.notifywithhtml');
@@ -1011,11 +1018,11 @@ sub verify_and_change_colors {
 	if (($color=~/^\#[0-9A-Fa-f]{6}$/) && (!$env{'form.resetall'})) {
 	    &Apache::lonnet::put('environment',{$entry => $color});
 	    &Apache::lonnet::appenv('environment.'.$entry => $color);
-	    $message.='Set '.$colortypes{$item}.' to '.$color.'<br />';
+	    $message.=&mt('Set '.$colortypes{$item}.' to ').'<tt>"'.$color.'"</tt>.<br />';
 	} else {
 	    &Apache::lonnet::del('environment',[$entry]);
 	    &Apache::lonnet::delenv('environment\.'.$entry);
-	    $message.='Reset '.$colortypes{$item}.'<br />';
+	    $message.=&mt('Reset '.$colortypes{$item}.'.').'<br />';
 	}
     }
     my $now = time;
@@ -1049,7 +1056,7 @@ sub passwordchanger {
             $defdom = $r->dir_config('lonDefDomain');
             my %data = &Apache::lonnet::tmpget($mailtoken);
             if (keys(%data) == 0) {
-                $r->print(&mt('Sorry, the URL you provided to complete the reset of your password was invalid.  Either the token included in the URL has been deleted or the URL you provided was invalid. Please submit a <a href="/adm/resetpw">new request</a> for a password reset, and follow the link to the new URL included in the e-mail that will be sent to you, to allow you to enter a new password.'));
+                $r->print(&mt('Sorry, the URL you provided to complete the reset of your password was invalid. Either the token included in the URL has been deleted or the URL you provided was invalid. Please submit a <a href="/adm/resetpw">new request</a> for a password reset, and follow the link to the new URL included in the e-mail that will be sent to you, to allow you to enter a new password.'));
                 return;
             }
             if (defined($data{time})) {
@@ -1321,23 +1328,23 @@ ENDERROR
         if ($currentpass ne $data{'temppasswd'}) {
             &passwordchanger($r,
                          '<span class="LC_error">'.
-                         &mt('Could not verify current authentication').'.  '.
-                         &mt('Please try again').'.</span>',$caller,$mailtoken);
+                         &mt('Could not verify current authentication.').'  '.
+                         &mt('Please try again.').'</span>',$caller,$mailtoken);
             return 1;
         }
     } 
     if ($newpass1 ne $newpass2) {
 	&passwordchanger($r,
 			 '<span class="LC_error">'.
-			 &mt('The new passwords you entered do not match').'.  '.
-			 &mt('Please try again').'.</span>',$caller,$mailtoken);
+			 &mt('The new passwords you entered do not match.').'  '.
+			 &mt('Please try again.').'</span>',$caller,$mailtoken);
 	return 1;
     }
     if (length($newpass1) < 7) {
 	&passwordchanger($r,
 			 '<span class="LC_error">'.
-			 &mt('Passwords must be a minimum of 7 characters long').'.  '.
-			 &mt('Please try again').'</span>.',$caller,$mailtoken);
+			 &mt('Passwords must be a minimum of 7 characters long.').'  '.
+			 &mt('Please try again.').'</span>',$caller,$mailtoken);
 	return 1;
     }
     #
@@ -1349,7 +1356,7 @@ ENDERROR
     if ($badpassword) {
 	# I can't figure out how to enter bad characters on my browser.
 	my $errormessage ='<span class="LC_error">'.
-           &mt('The password you entered contained illegal characters').'.<br />'.
+           &mt('The password you entered contained illegal characters.').'<br />'.
            &mt('Valid characters are').(<<"ENDERROR");
 : space and <br />
 <pre>
@@ -1370,7 +1377,7 @@ ENDERROR
     } else {
 	# error error: run in circles, scream and shout
         $r->print("<h3><span class='LC_error'>".&mt("The password for [_1] was not changed",$user)."</span></h3>".
-                  &mt('Please make sure your old password was entered correctly').'.');
+                  &mt('Please make sure your old password was entered correctly.'));
         return 1;
     }
     return;
@@ -1490,11 +1497,11 @@ sub verify_and_change_discussion {
     if (defined($env{'form.discdisp'}) ) {
         my $newdisp  = $env{'form.newdisp'};
         if ($newdisp eq 'unread') {
-            $message .='In discussions: only new posts will be displayed.<br />';
+            $message .=&mt('In discussions: only new posts will be displayed.').'<br />';
             &Apache::lonnet::put('environment',{'discdisplay' => $newdisp});
             &Apache::lonnet::appenv('environment.discdisplay' => $newdisp);
         } else {
-            $message .= 'In discussions: all posts will be displayed.<br />';
+            $message .= &mt('In discussions: all posts will be displayed.').'<br />';
             &Apache::lonnet::del('environment',['discdisplay']);
             &Apache::lonnet::delenv('environment\.discdisplay');
         }
@@ -1502,11 +1509,11 @@ sub verify_and_change_discussion {
     if (defined($env{'form.discmark'}) ) {
         my $newmark = $env{'form.newmark'};
         if ($newmark eq 'ondisp') {
-           $message.='In discussions: new posts will be cease to be identified as "new" after display.<br />';
+           $message.=&mt('In discussions: new posts will be cease to be identified as "NEW" after display.').'<br />';
             &Apache::lonnet::put('environment',{'discmarkread' => $newmark});
             &Apache::lonnet::appenv('environment.discmarkread' => $newmark);
         } else {
-            $message.='In discussions: posts will be identified as "new" until marked as read by the reader.<br />';
+            $message.=&mt('In discussions: posts will be identified as "NEW" until marked as read by the reader.').'<br />';
             &Apache::lonnet::del('environment',['discmarkread']);
             &Apache::lonnet::delenv('environment\.discmarkread');
         }
@@ -1661,16 +1668,17 @@ sub handler {
     push (@Options,({ action   => 'changemsgforward',
                       linktext => 'Change Message Forwarding and Notification Email Addresses',
                       href     => '/adm/preferences',
-                      help     => 'Prefs_Forwarding',
+                      help     => 'Prefs_Messages',
                       breadcrumb => 
                           { href => '/adm/preferences?action=changemsgforward',
-                            text => 'Change Message Forwarding'},
+                            text => 'Change Message Forwarding/Notification'},
                       subroutine => \&msgforwardchanger,
                       },
                     { action => 'verify_and_change_msgforward',
+                      help   => 'Prefs_Messages',
                       breadcrumb => 
                           { href => '/adm/preferences?action=changemsgforward',
-                            text => 'Change Message Forwarding'},
+                            text => 'Change Message Forwarding/Notification'},
                       printmenu => 'no',
                       subroutine => \&verify_and_change_msgforward }));
     my $aboutmeaction=
