@@ -1,5 +1,5 @@
 #
-# $Id: lonsupportreq.pm,v 1.46 2008/01/13 16:53:46 raeburn Exp $
+# $Id: lonsupportreq.pm,v 1.47 2008/01/29 17:36:56 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -762,17 +762,20 @@ sub print_header {
                                            login => 'Log-in help',
                                            ask   => 'Ask helpdesk',
                                            getst => 'Getting started guide',
-                                           back =>  'Back to last location'
+                                           back =>  'Back to last location',
+                                           headline => 'help/support',
                                          );
-    my ($getstartlink,$getstarttext);
+    my ($getstartlink,$reviewtext);
     if (-e $Apache::lonnet::perlvar{'lonDocRoot'}.'/adm/gettingstarted.html') {
         $getstartlink = qq|<td align="center">&nbsp;<b><a href="/adm/gettingstarted.html">$lt{'getst'}</a></td>|;
-        $getstarttext = ' '.&mt('and the "Getting started" guide').' ';
+        $reviewtext = &mt('Please review the information in "Log-in help" and the "Getting started" guide if you are unable to log-in.');
+    } else {
+        $reviewtext = &mt('Please review the information in "Log-in help" if you are unable to log-in.');
     }
     $r->print(<<END);
 <table width="620" border="0" cellspacing="0" cellpadding="0" height="55">   <tr height="50">    <td width='5'>&nbsp;</td>
    <td>
-    <fieldset><legend><img src="$location/lonIcons/minilogo.gif" height='20' width='29' valign='bottom' />&nbsp;&nbsp;<b><font size="+1">LON-CAPA help/support</font></b></legend>
+    <fieldset><legend><img src="$location/lonIcons/minilogo.gif" height='20' width='29' valign='bottom' />&nbsp;&nbsp;<b><font size="+1">LON-CAPA $lt{'headline'}</font></b></legend>
  <table id="LC_helpmenu_links">
    <tr>
     <td align="center"><span class="LC_nobreak"><img src="$location/help/gif/smallHelp.gif" border="0" alt="($lt{'login'})" valign="middle" />&nbsp;<b><a href="/adm/loginproblems.html">$lt{'login'}</a></b>&nbsp;</span></td>
@@ -791,8 +794,11 @@ END
     if  ($command ne 'process') {
         $r->print('
  <tr>
-  <td colspan="3">'.&mt('
-Please review the information in "Log-in help"').$getstarttext.' '.&mt('if you are unable to log-in').'.  '.&mt('If your problem is still unresolved, the form below can be used to send a question to the LON-CAPA helpdesk').'.<br /><font size="-1"><b>'.&mt('Students').'</b>: '.&mt('Do <b>not</b> use this form to ask questions about course content.').' '.&mt('Contact your instructor instead.').'</font><br /><br />
+  <td colspan="3">'.$reviewtext.' '
+.&mt('If your problem is still unresolved, the form below can be used to send a question to the LON-CAPA helpdesk.').'<br />'
+.'<font size="-1"><b>'.&mt('Students').'</b>: '.&mt('Do <b>not</b> use this form to ask questions about course content.').' '
+.&mt('Contact your instructor instead.')
+.'</font><br /><br />
   </td>
  </tr>');
     }
