@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to display the classlist 
 #
-# $Id: lonviewclasslist.pm,v 1.8 2007/07/20 00:15:06 raeburn Exp $
+# $Id: lonviewclasslist.pm,v 1.9 2007/09/07 00:09:07 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -275,7 +275,7 @@ sub html_classlist {
                     $link = '<a href="/adm/'.$domain.'/'.$username.'/aboutme/portfolio?classlist">'.$link.'</a>'; 
                 }
             } else {
-                $link = &mt("Error retrieving file information.");
+                $link = '<span class="LC_error">'.&mt("Error retrieving file information.").'</span>';
             }
             $Str .= '<td>'.$link.'</td>';
         }
@@ -342,10 +342,10 @@ sub process_student_prefs {
             if ($result eq 'ok') {
                 $output .= &mt('Display of your name in the student-viewable roster set to <b>[_1]</b>.',$visibility);
             } else {
-                $output .= &mt('Error occurred saving display setting.');
+                $output .= '<span class="LC_error">'.&mt('Error occurred saving display setting.').'</span>';
             }
         } else {
-            $output .= &mt('Error occurred saving display setting.');
+            $output .= '<span class="LC_error">'.&mt('Error occurred saving display setting.').'</span>';
         }
     } else {
         $output .= &mt('Display of your name in the student-viewable roster unchanged (set to <b>[_1]</b>).',$visibility);
