@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemstatistics.pm,v 1.111 2006/12/06 22:22:38 albertel Exp $
+# $Id: lonproblemstatistics.pm,v 1.112 2008/01/14 14:32:49 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1593,16 +1593,16 @@ sub get_statistics {
         ($data->{'num_solved'}+0.1);
     #
     # Get the due date for research purposes (commented out most of the time)
-#    $data->{'duedate'} = 
-#        &Apache::lonnet::EXT('resource.'.$part.'.duedate',$symb);
-#    $data->{'opendate'} = 
-#        &Apache::lonnet::EXT('resource.'.$part.'.opendate',$symb);
-#    $data->{'maxtries'} = 
-#        &Apache::lonnet::EXT('resource.'.$part.'.maxtries',$symb);
-#    $data->{'hinttries'} =
-#        &Apache::lonnet::EXT('resource.'.$part.'.hinttries',$symb);
-    $data->{'weight'} =
-        &Apache::lonnet::EXT('resource.'.$part.'.weight',$symb);
+#    my $duedate = &Apache::lonnet::EXT('resource.'.$part.'.duedate',$symb);;
+#    my $opendate = &Apache::lonnet::EXT('resource.'.$part.'.opendate',$symb);
+#    my $maxtries = &Apache::lonnet::EXT('resource.'.$part.'.maxtries',$symb);
+#    my $hinttries = &Apache::lonnet::EXT('resource.'.$part.'.hinttries',$symb);
+    my $weight = &Apache::lonnet::EXT('resource.'.$part.'.weight',$symb);
+    $data->{'weight'} = $weight;
+#    $data->{'duedate'} = $duedate; 
+#    $data->{'opendate'} = $opendate;
+#    $data->{'maxtries'} = $maxtries;
+#    $data->{'hinttries'} = $hinttries;
 #    $data->{'resptypes'} = join(',',@{$resource->{'partdata'}->{$part}->{'ResponseTypes'}});
     return $data;
 }
